14 AcceptOutcome — result of accepting an input.
Structs
- Coarse
Admission Flags - Coarse accept flags used by the MeerkatMachine DSL’s
AcceptWithCompletionbranches. - Resolved
Admission - Machine-owned resolution of an accepted input’s semantic admission path.
Enums
- Accept
Outcome - Outcome of
RuntimeDriver::accept_input(). - Admission
Plan - Machine-owned admission plan for an accepted input.
- Admission
Queue Action - Machine-owned queue action for an admitted input.
- Existing
Queued Admission Action - Machine-owned action against an existing queued input.
- Reject
Reason - Typed reason why an input was rejected at the accept boundary.
Functions
- handling_
mode_ from_ policy - Derive the handling mode from a resolved policy decision.