#[non_exhaustive]pub enum RejectReason {
NotReady {
state: String,
},
DurabilityViolation {
detail: String,
},
PeerHandlingModeInvalid {
detail: String,
},
}Expand description
Typed reason why an input was rejected at the accept boundary.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotReady
Runtime is not in a state that accepts input (e.g. stopped, destroyed).
DurabilityViolation
Input failed durability validation.
PeerHandlingModeInvalid
Peer input carried a forbidden handling_mode.