pub struct CompletionRegistrySnapshot {
pub input_count: usize,
pub waiter_count: usize,
pub waiting_inputs: Vec<CompletionWaiterEntrySnapshot>,
}Expand description
Diagnostic snapshot of the completion waiter registry.
This makes the carrier explicit for MeerkatMachine mapping work without promoting waiter plumbing into canonical runtime semantics.
Fields
input_count: usizewaiter_count: usizewaiting_inputs: Vec<CompletionWaiterEntrySnapshot>Trait Implementations
Sourceimpl Clone for CompletionRegistrySnapshot
impl Clone for CompletionRegistrySnapshot
Sourcefn clone(&self) -> CompletionRegistrySnapshot
fn clone(&self) -> CompletionRegistrySnapshot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompletionRegistrySnapshot
impl Debug for CompletionRegistrySnapshot
Sourceimpl Default for CompletionRegistrySnapshot
impl Default for CompletionRegistrySnapshot
Sourcefn default() -> CompletionRegistrySnapshot
fn default() -> CompletionRegistrySnapshot
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for CompletionRegistrySnapshot
impl PartialEq for CompletionRegistrySnapshot
Sourcefn eq(&self, other: &CompletionRegistrySnapshot) -> bool
fn eq(&self, other: &CompletionRegistrySnapshot) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CompletionRegistrySnapshot
impl StructuralPartialEq for CompletionRegistrySnapshot