pub struct PolicyVersion(pub u64);Expand description
Version of the generated admission policy used for a decision.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for PolicyVersion
impl Clone for PolicyVersion
Sourcefn clone(&self) -> PolicyVersion
fn clone(&self) -> PolicyVersion
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PolicyVersion
Sourceimpl Debug for PolicyVersion
impl Debug for PolicyVersion
Sourceimpl<'de> Deserialize<'de> for PolicyVersion
impl<'de> Deserialize<'de> for PolicyVersion
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for PolicyVersion
impl Display for PolicyVersion
impl Eq for PolicyVersion
Sourceimpl Hash for PolicyVersion
impl Hash for PolicyVersion
Sourceimpl PartialEq for PolicyVersion
impl PartialEq for PolicyVersion
Sourcefn eq(&self, other: &PolicyVersion) -> bool
fn eq(&self, other: &PolicyVersion) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PolicyVersion
impl Serialize for PolicyVersion
impl StructuralPartialEq for PolicyVersion