pub struct RuntimeSessionLifecycleObservation { /* private fields */ }Expand description
Exact durable lifecycle observation for one session registration target.
Construction is owned by MeerkatMachine so a raw-content version observed for one runtime id cannot be replayed as the precondition for another.
Implementations
Sourceimpl RuntimeSessionLifecycleObservation
impl RuntimeSessionLifecycleObservation
pub fn session_id(&self) -> &SessionId
pub fn runtime_id(&self) -> &LogicalRuntimeId
pub fn lifecycle(&self) -> &MachineLifecycleObservation