Module runtime_state

Module runtime_state 

22 RuntimeState — the runtime’s public state projection.

Canonical live transition legality lives in the checked-in MeerkatMachine plus the runtime driver that realizes its coarse control transitions.

Structs

RuntimeStateTransitionError
Error when an invalid runtime state transition is attempted.

Enums

RuntimeState
The state of a runtime instance.