#[non_exhaustive]pub enum RuntimeState {
Initializing,
Idle,
Attached,
Running,
Retired,
Stopped,
Destroyed,
}Expand description
The state of a runtime instance.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Initializing
Initializing (first state after creation).
Idle
Idle — no executor attached, no run in progress, ready to accept input.
Attached
Attached — executor attached, runtime loop alive, waiting for input.
Running
A run is in progress.
Retired
Retired — no longer accepting new input, draining existing.
Stopped
Stopped by runtime control; generated lifecycle authority classifies this as non-terminal while the runtime can still be recovered or destroyed.
Destroyed
Destroyed (terminal).