pub struct ExactInputStateObservation { /* private fields */ }Expand description
Exact stored input row resolved through the durable idempotency-key index.
Implementations
Sourceimpl ExactInputStateObservation
impl ExactInputStateObservation
Sourcepub fn from_exact_stored_row(
state: StoredInputState,
exact_row_digest: String,
) -> Result<Self, RuntimeStoreError>
pub fn from_exact_stored_row( state: StoredInputState, exact_row_digest: String, ) -> Result<Self, RuntimeStoreError>
Bind a decoded state to the exact bytes the store resolved.
Sourcepub fn state(&self) -> &StoredInputState
pub fn state(&self) -> &StoredInputState
Decoded stored input state.
Sourcepub fn exact_row_digest(&self) -> &str
pub fn exact_row_digest(&self) -> &str
Exact digest of the backend row bytes observed with the lookup.
Sourcepub fn into_parts(self) -> (StoredInputState, String)
pub fn into_parts(self) -> (StoredInputState, String)
Consume the observation into decoded state and exact row digest.