pub struct MachineLifecycleBindingFacts { /* private fields */ }Expand description
Runtime binding facts selected by generated MeerkatMachine authority.
RuntimeStore implementations persist and read these facts as part of a machine lifecycle snapshot. The commit token that writes these facts stays crate-private so compatibility callers cannot mint replacement lifecycle truth.
Implementations
Sourceimpl MachineLifecycleBindingFacts
impl MachineLifecycleBindingFacts
pub fn agent_runtime_id(&self) -> Option<&str>
pub fn fence_token(&self) -> Option<u64>
pub fn runtime_generation(&self) -> Option<u64>
pub fn runtime_epoch_id(&self) -> Option<&str>