pub struct CompletionHandle { /* private fields */ }Expand description
Handle for awaiting the completion of an accepted input.
Implementations
Sourceimpl CompletionHandle
impl CompletionHandle
Sourcepub async fn wait(self) -> CompletionOutcome
pub async fn wait(self) -> CompletionOutcome
Wait for the input to reach a terminal state.
Sourcepub fn already_resolved(outcome: CompletionOutcome) -> Self
pub fn already_resolved(outcome: CompletionOutcome) -> Self
Create a handle from a pre-resolved outcome.
Used when the input is already terminal (e.g. dedup of completed input) and no waiter registration is needed.