#[non_exhaustive]pub enum ApplyMode {
StageRunStart,
StageRunBoundary,
InjectNow,
Ignore,
}Expand description
How the input should be applied to the conversation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
StageRunStart
Stage for application at the start of the next run.
StageRunBoundary
Stage for application at any run boundary (start or checkpoint).
InjectNow
Inject immediately (no run boundary required).
Ignore
Do not apply (input is informational only).