22 RuntimeState — the runtime’s public state projection.
Canonical live transition legality lives in the checked-in MeerkatMachine
plus the runtime driver that realizes its coarse control transitions.
Structs
- Runtime
State Transition Error - Error when an invalid runtime state transition is attempted.
Enums
- Runtime
State - The state of a runtime instance.