Module runtime_state

Module runtime_state 

22 RuntimeState — the runtime’s public state projection.

Canonical live transition legality lives in the checked-in MeerkatMachine plus the runtime driver that realizes its coarse control transitions.

Structs

RuntimeStateTransitionError
Error when an invalid runtime state transition is attempted.

Enums

RuntimeState
The state of a runtime instance.

Functions

run_return_phase_from_pre_run_phase
Classify the machine-owned coarse phase a run should return to after a terminal outcome.
run_start_pre_phase_from_phase
Classify the machine-owned pre-run phase that should be remembered when a new run starts from the current coarse runtime phase.