22 RuntimeState — the runtime’s public state projection.
Canonical live transition legality lives in the checked-in MeerkatMachine
plus the runtime driver that realizes its coarse control transitions.
Structs
- Runtime
State Transition Error - Error when an invalid runtime state transition is attempted.
Enums
- Runtime
State - The state of a runtime instance.
Functions
- run_
return_ phase_ from_ pre_ run_ phase - Classify the machine-owned coarse phase a run should return to after a terminal outcome.
- run_
start_ pre_ phase_ from_ phase - Classify the machine-owned pre-run phase that should be remembered when a new run starts from the current coarse runtime phase.