#[non_exhaustive]pub enum RuntimeDriverError {
NotReady {
state: RuntimeState,
},
NotFound {
runtime_id: LogicalRuntimeId,
},
ValidationFailed {
reason: String,
},
Destroyed,
RecoveryCorruption {
reason: String,
},
Internal(String),
}Expand description
Errors from RuntimeDriver operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotReady
The runtime is not in a state that can accept this operation.
Fields

state: RuntimeStateNotFound
The runtime was never registered / does not exist.
Distinct from RuntimeDriverError::Destroyed and
RuntimeDriverError::NotReady with a Destroyed state: absence means
the runtime id was never admitted, not that it once existed and was torn
down.
Fields

runtime_id: LogicalRuntimeIdValidationFailed
Input validation failed.
Destroyed
The runtime has been destroyed.
RecoveryCorruption
Durable recovery state could not be replayed through canonical runtime authority.
Internal(String)
Internal error.